django-memoize
==============

.. image:: https://travis-ci.org/tvavrys/django-memoize.svg?branch=master
    :target: https://travis-ci.org/tvavrys/django-memoize
.. image:: https://badge.fury.io/py/django-memoize.svg
    :target: http://badge.fury.io/py/django-memoize
|
**django-memoize** is an implementation
of `memoization <http://en.wikipedia.org/wiki/Memoization>`_ technique
for Django. You can think of it as a cache for function or method results.


Documentation
-------------

Documentation is available at http://pythonhosted.org/django-memoize/.

Requirements
------------

Django >= 1.4 is required.
